@@ -2,12 +2,10 @@ package Nagios::Passive::Base;
 
 use strict;
 use Carp;
-use File::Temp;
 use Fcntl qw/:DEFAULT :flock/;
 use Nagios::Plugin::Threshold;
 use Nagios::Plugin::Performance;
 Nagios::Plugin::Functions::_use_die(1);
-use version; our $VERSION = qv('0.1.0');
 use overload '""' => 'to_string';
 use Moose;
 
@@ -85,8 +83,8 @@ sub _quoted_output {
   my $self = shift;
   my $output = $self->output;
   # remove trailing newlines and quote the remaining ones
-  $output =~ s/(?:\r?\n)*$//;
-  $output =~ s/\n/\\n/g;
+  $output =~ s/[\r\n]*$//o;
+  $output =~ s/\n/\\n/go;
   if($self->has_performance) {
     return $output . " | ".$self->_perf_string;
   }
